# exchange-ob
Orderbook code for all exchanges

# To create editable file
pip install -e .

# To run test
python -m unittest discover -s tests


# To run single test
python -m unittest tests.test_my_module.TestMyModule.test_bitmart_connection